All this code was done by Gaëtan Delannay, ao all the credits belong to him.
The original project is available here: https://forge.pallavi.be/projects/appy

I liked the idea of odf templates very much, but there was no python3 port available.
So here it is.
